@@ -7,6 +7,7 @@ Helpers for unit tests
 
 from __future__ import annotations
 
+import os
 import sys
 from contextlib import AbstractContextManager
 from difflib import unified_diff
@@ -19,7 +20,15 @@ from .commands import Command
 from .core import CommandType, get_params
 from .exceptions import UsageError
 
-__all__ = ['ParserTest', 'RedirectStreams', 'format_diff', 'get_rst_text', 'get_help_text', 'get_usage_text']
+__all__ = [
+    'ParserTest',
+    'RedirectStreams',
+    'Environment',
+    'format_diff',
+    'get_rst_text',
+    'get_help_text',
+    'get_usage_text',
+]
 
 Argv = List[str]
 Expected = Dict[str, Any]
@@ -236,16 +245,32 @@ class RedirectStreams(AbstractContextManager):
             setattr(sys, name, orig)
 
 
+class Environment(AbstractContextManager):
+    __slots__ = ('original', 'overrides')
+
+    def __init__(self, **env):
+        self.overrides = env
+
+    def __enter__(self):
+        self.original = os.environ.copy()
+        os.environ.clear()
+        os.environ.update(self.overrides)
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        os.environ.clear()
+        os.environ.update(self.original)
+
+
 def get_usage_text(cmd: Type[Command]) -> str:
     with cmd().ctx:
         return get_params(cmd).formatter.format_usage()
 
 
-def get_help_text(cmd: Union[Type[Command], Command]) -> str:
+def get_help_text(cmd: Union[Type[Command], Command], terminal_width: int = 199) -> str:
     if not isinstance(cmd, Command):
         cmd = cmd()
 
-    cmd.ctx._terminal_width = 199
+    cmd.ctx._terminal_width = terminal_width
     with cmd.ctx:
         return get_params(cmd).formatter.format_help()
 
